/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataMongodbatlasFlexRestoreJobConfig extends cdktf.TerraformMetaArguments {
    /**
    * Human-readable label that identifies the flex cluster whose snapshot you want to restore.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.37.0/docs/data-sources/flex_restore_job#name DataMongodbatlasFlexRestoreJob#name}
    */
    readonly name: string;
    /**
    * Unique 24-hexadecimal digit string that identifies your project. Use the [/groups](#tag/Projects/operation/listProjects) endpoint to retrieve all projects to which the authenticated user has access.
    *
    * **NOTE**: Groups and projects are synonymous terms. Your group id is the same as your project id. For existing groups, your group/project id remains the same. The resource and corresponding endpoints use the term groups.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.37.0/docs/data-sources/flex_restore_job#project_id DataMongodbatlasFlexRestoreJob#project_id}
    */
    readonly projectId: string;
    /**
    * Unique 24-hexadecimal digit string that identifies the restore job.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.37.0/docs/data-sources/flex_restore_job#restore_job_id DataMongodbatlasFlexRestoreJob#restore_job_id}
    */
    readonly restoreJobId: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.37.0/docs/data-sources/flex_restore_job mongodbatlas_flex_restore_job}
*/
export declare class DataMongodbatlasFlexRestoreJob extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "mongodbatlas_flex_restore_job";
    /**
    * Generates CDKTF code for importing a DataMongodbatlasFlexRestoreJob resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataMongodbatlasFlexRestoreJob to import
    * @param importFromId The id of the existing DataMongodbatlasFlexRestoreJob that should be imported. Refer to the {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.37.0/docs/data-sources/flex_restore_job#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataMongodbatlasFlexRestoreJob to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.37.0/docs/data-sources/flex_restore_job mongodbatlas_flex_restore_job} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataMongodbatlasFlexRestoreJobConfig
    */
    constructor(scope: Construct, id: string, config: DataMongodbatlasFlexRestoreJobConfig);
    get deliveryType(): string;
    get expirationDate(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _projectId?;
    get projectId(): string;
    set projectId(value: string);
    get projectIdInput(): string | undefined;
    get restoreFinishedDate(): string;
    private _restoreJobId?;
    get restoreJobId(): string;
    set restoreJobId(value: string);
    get restoreJobIdInput(): string | undefined;
    get restoreScheduledDate(): string;
    get snapshotFinishedDate(): string;
    get snapshotId(): string;
    get snapshotUrl(): string;
    get status(): string;
    get targetDeploymentItemName(): string;
    get targetProjectId(): string;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
