/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataMongodbatlasResourcePolicyConfig extends cdktf.TerraformMetaArguments {
    /**
    * Unique 24-hexadecimal digit string that identifies an Atlas resource policy.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.37.0/docs/data-sources/resource_policy#id DataMongodbatlasResourcePolicy#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * Unique 24-hexadecimal digit string that identifies the organization that contains your projects. Use the [/orgs](#tag/Organizations/operation/listOrganizations) endpoint to retrieve all organizations to which the authenticated user has access.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.37.0/docs/data-sources/resource_policy#org_id DataMongodbatlasResourcePolicy#org_id}
    */
    readonly orgId: string;
}
export interface DataMongodbatlasResourcePolicyCreatedByUser {
}
export declare function dataMongodbatlasResourcePolicyCreatedByUserToTerraform(struct?: DataMongodbatlasResourcePolicyCreatedByUser): any;
export declare function dataMongodbatlasResourcePolicyCreatedByUserToHclTerraform(struct?: DataMongodbatlasResourcePolicyCreatedByUser): any;
export declare class DataMongodbatlasResourcePolicyCreatedByUserOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataMongodbatlasResourcePolicyCreatedByUser | undefined;
    set internalValue(value: DataMongodbatlasResourcePolicyCreatedByUser | undefined);
    get id(): string;
    get name(): string;
}
export interface DataMongodbatlasResourcePolicyLastUpdatedByUser {
}
export declare function dataMongodbatlasResourcePolicyLastUpdatedByUserToTerraform(struct?: DataMongodbatlasResourcePolicyLastUpdatedByUser): any;
export declare function dataMongodbatlasResourcePolicyLastUpdatedByUserToHclTerraform(struct?: DataMongodbatlasResourcePolicyLastUpdatedByUser): any;
export declare class DataMongodbatlasResourcePolicyLastUpdatedByUserOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataMongodbatlasResourcePolicyLastUpdatedByUser | undefined;
    set internalValue(value: DataMongodbatlasResourcePolicyLastUpdatedByUser | undefined);
    get id(): string;
    get name(): string;
}
export interface DataMongodbatlasResourcePolicyPolicies {
}
export declare function dataMongodbatlasResourcePolicyPoliciesToTerraform(struct?: DataMongodbatlasResourcePolicyPolicies): any;
export declare function dataMongodbatlasResourcePolicyPoliciesToHclTerraform(struct?: DataMongodbatlasResourcePolicyPolicies): any;
export declare class DataMongodbatlasResourcePolicyPoliciesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataMongodbatlasResourcePolicyPolicies | undefined;
    set internalValue(value: DataMongodbatlasResourcePolicyPolicies | undefined);
    get body(): string;
    get id(): string;
}
export declare class DataMongodbatlasResourcePolicyPoliciesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataMongodbatlasResourcePolicyPoliciesOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.37.0/docs/data-sources/resource_policy mongodbatlas_resource_policy}
*/
export declare class DataMongodbatlasResourcePolicy extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "mongodbatlas_resource_policy";
    /**
    * Generates CDKTF code for importing a DataMongodbatlasResourcePolicy resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataMongodbatlasResourcePolicy to import
    * @param importFromId The id of the existing DataMongodbatlasResourcePolicy that should be imported. Refer to the {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.37.0/docs/data-sources/resource_policy#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataMongodbatlasResourcePolicy to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.37.0/docs/data-sources/resource_policy mongodbatlas_resource_policy} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataMongodbatlasResourcePolicyConfig
    */
    constructor(scope: Construct, id: string, config: DataMongodbatlasResourcePolicyConfig);
    private _createdByUser;
    get createdByUser(): DataMongodbatlasResourcePolicyCreatedByUserOutputReference;
    get createdDate(): string;
    get description(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _lastUpdatedByUser;
    get lastUpdatedByUser(): DataMongodbatlasResourcePolicyLastUpdatedByUserOutputReference;
    get lastUpdatedDate(): string;
    get name(): string;
    private _orgId?;
    get orgId(): string;
    set orgId(value: string);
    get orgIdInput(): string | undefined;
    private _policies;
    get policies(): DataMongodbatlasResourcePolicyPoliciesList;
    get version(): string;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
