/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface FlexClusterConfig extends cdktf.TerraformMetaArguments {
    /**
    * Human-readable label that identifies the instance.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.37.0/docs/resources/flex_cluster#name FlexCluster#name}
    */
    readonly name: string;
    /**
    * Unique 24-hexadecimal character string that identifies the project.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.37.0/docs/resources/flex_cluster#project_id FlexCluster#project_id}
    */
    readonly projectId: string;
    /**
    * Group of cloud provider settings that configure the provisioned MongoDB flex cluster.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.37.0/docs/resources/flex_cluster#provider_settings FlexCluster#provider_settings}
    */
    readonly providerSettings: FlexClusterProviderSettings;
    /**
    * Map that contains key-value pairs between 1 to 255 characters in length for tagging and categorizing the instance.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.37.0/docs/resources/flex_cluster#tags FlexCluster#tags}
    */
    readonly tags?: {
        [key: string]: string;
    };
    /**
    * Flag that indicates whether termination protection is enabled on the cluster. If set to `true`, MongoDB Cloud won't delete the cluster. If set to `false`, MongoDB Cloud will delete the cluster.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.37.0/docs/resources/flex_cluster#termination_protection_enabled FlexCluster#termination_protection_enabled}
    */
    readonly terminationProtectionEnabled?: boolean | cdktf.IResolvable;
}
export interface FlexClusterBackupSettings {
}
export declare function flexClusterBackupSettingsToTerraform(struct?: FlexClusterBackupSettings): any;
export declare function flexClusterBackupSettingsToHclTerraform(struct?: FlexClusterBackupSettings): any;
export declare class FlexClusterBackupSettingsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): FlexClusterBackupSettings | undefined;
    set internalValue(value: FlexClusterBackupSettings | undefined);
    get enabled(): cdktf.IResolvable;
}
export interface FlexClusterConnectionStrings {
}
export declare function flexClusterConnectionStringsToTerraform(struct?: FlexClusterConnectionStrings): any;
export declare function flexClusterConnectionStringsToHclTerraform(struct?: FlexClusterConnectionStrings): any;
export declare class FlexClusterConnectionStringsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): FlexClusterConnectionStrings | undefined;
    set internalValue(value: FlexClusterConnectionStrings | undefined);
    get standard(): string;
    get standardSrv(): string;
}
export interface FlexClusterProviderSettings {
    /**
    * Cloud service provider on which MongoDB Cloud provisioned the flex cluster.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.37.0/docs/resources/flex_cluster#backing_provider_name FlexCluster#backing_provider_name}
    */
    readonly backingProviderName: string;
    /**
    * Human-readable label that identifies the geographic location of your MongoDB flex cluster. The region you choose can affect network latency for clients accessing your databases. For a complete list of region names, see [AWS](https://docs.atlas.mongodb.com/reference/amazon-aws/#std-label-amazon-aws), [GCP](https://docs.atlas.mongodb.com/reference/google-gcp/), and [Azure](https://docs.atlas.mongodb.com/reference/microsoft-azure/).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.37.0/docs/resources/flex_cluster#region_name FlexCluster#region_name}
    */
    readonly regionName: string;
}
export declare function flexClusterProviderSettingsToTerraform(struct?: FlexClusterProviderSettings | cdktf.IResolvable): any;
export declare function flexClusterProviderSettingsToHclTerraform(struct?: FlexClusterProviderSettings | cdktf.IResolvable): any;
export declare class FlexClusterProviderSettingsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): FlexClusterProviderSettings | cdktf.IResolvable | undefined;
    set internalValue(value: FlexClusterProviderSettings | cdktf.IResolvable | undefined);
    private _backingProviderName?;
    get backingProviderName(): string;
    set backingProviderName(value: string);
    get backingProviderNameInput(): string | undefined;
    get diskSizeGb(): number;
    get providerName(): string;
    private _regionName?;
    get regionName(): string;
    set regionName(value: string);
    get regionNameInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.37.0/docs/resources/flex_cluster mongodbatlas_flex_cluster}
*/
export declare class FlexCluster extends cdktf.TerraformResource {
    static readonly tfResourceType = "mongodbatlas_flex_cluster";
    /**
    * Generates CDKTF code for importing a FlexCluster resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the FlexCluster to import
    * @param importFromId The id of the existing FlexCluster that should be imported. Refer to the {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.37.0/docs/resources/flex_cluster#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the FlexCluster to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.37.0/docs/resources/flex_cluster mongodbatlas_flex_cluster} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options FlexClusterConfig
    */
    constructor(scope: Construct, id: string, config: FlexClusterConfig);
    private _backupSettings;
    get backupSettings(): FlexClusterBackupSettingsOutputReference;
    get clusterType(): string;
    private _connectionStrings;
    get connectionStrings(): FlexClusterConnectionStringsOutputReference;
    get createDate(): string;
    get id(): string;
    get mongoDbVersion(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _projectId?;
    get projectId(): string;
    set projectId(value: string);
    get projectIdInput(): string | undefined;
    private _providerSettings;
    get providerSettings(): FlexClusterProviderSettingsOutputReference;
    putProviderSettings(value: FlexClusterProviderSettings): void;
    get providerSettingsInput(): cdktf.IResolvable | FlexClusterProviderSettings | undefined;
    get stateName(): string;
    private _tags?;
    get tags(): {
        [key: string]: string;
    };
    set tags(value: {
        [key: string]: string;
    });
    resetTags(): void;
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _terminationProtectionEnabled?;
    get terminationProtectionEnabled(): boolean | cdktf.IResolvable;
    set terminationProtectionEnabled(value: boolean | cdktf.IResolvable);
    resetTerminationProtectionEnabled(): void;
    get terminationProtectionEnabledInput(): boolean | cdktf.IResolvable | undefined;
    get versionReleaseSystem(): string;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
