/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ResourcePolicyConfig extends cdktf.TerraformMetaArguments {
    /**
    * Description of the Atlas resource policy.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.37.0/docs/resources/resource_policy#description ResourcePolicy#description}
    */
    readonly description?: string;
    /**
    * Human-readable label that describes the Atlas resource policy.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.37.0/docs/resources/resource_policy#name ResourcePolicy#name}
    */
    readonly name: string;
    /**
    * Unique 24-hexadecimal digit string that identifies the organization that contains your projects. Use the [/orgs](#tag/Organizations/operation/listOrganizations) endpoint to retrieve all organizations to which the authenticated user has access.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.37.0/docs/resources/resource_policy#org_id ResourcePolicy#org_id}
    */
    readonly orgId: string;
    /**
    * List of policies that make up the Atlas resource policy.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.37.0/docs/resources/resource_policy#policies ResourcePolicy#policies}
    */
    readonly policies: ResourcePolicyPolicies[] | cdktf.IResolvable;
}
export interface ResourcePolicyCreatedByUser {
}
export declare function resourcePolicyCreatedByUserToTerraform(struct?: ResourcePolicyCreatedByUser): any;
export declare function resourcePolicyCreatedByUserToHclTerraform(struct?: ResourcePolicyCreatedByUser): any;
export declare class ResourcePolicyCreatedByUserOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ResourcePolicyCreatedByUser | undefined;
    set internalValue(value: ResourcePolicyCreatedByUser | undefined);
    get id(): string;
    get name(): string;
}
export interface ResourcePolicyLastUpdatedByUser {
}
export declare function resourcePolicyLastUpdatedByUserToTerraform(struct?: ResourcePolicyLastUpdatedByUser): any;
export declare function resourcePolicyLastUpdatedByUserToHclTerraform(struct?: ResourcePolicyLastUpdatedByUser): any;
export declare class ResourcePolicyLastUpdatedByUserOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ResourcePolicyLastUpdatedByUser | undefined;
    set internalValue(value: ResourcePolicyLastUpdatedByUser | undefined);
    get id(): string;
    get name(): string;
}
export interface ResourcePolicyPolicies {
    /**
    * A string that defines the permissions for the policy. The syntax used is the Cedar Policy language.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.37.0/docs/resources/resource_policy#body ResourcePolicy#body}
    */
    readonly body: string;
}
export declare function resourcePolicyPoliciesToTerraform(struct?: ResourcePolicyPolicies | cdktf.IResolvable): any;
export declare function resourcePolicyPoliciesToHclTerraform(struct?: ResourcePolicyPolicies | cdktf.IResolvable): any;
export declare class ResourcePolicyPoliciesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ResourcePolicyPolicies | cdktf.IResolvable | undefined;
    set internalValue(value: ResourcePolicyPolicies | cdktf.IResolvable | undefined);
    private _body?;
    get body(): string;
    set body(value: string);
    get bodyInput(): string | undefined;
    get id(): string;
}
export declare class ResourcePolicyPoliciesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ResourcePolicyPolicies[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ResourcePolicyPoliciesOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.37.0/docs/resources/resource_policy mongodbatlas_resource_policy}
*/
export declare class ResourcePolicy extends cdktf.TerraformResource {
    static readonly tfResourceType = "mongodbatlas_resource_policy";
    /**
    * Generates CDKTF code for importing a ResourcePolicy resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the ResourcePolicy to import
    * @param importFromId The id of the existing ResourcePolicy that should be imported. Refer to the {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.37.0/docs/resources/resource_policy#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the ResourcePolicy to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.37.0/docs/resources/resource_policy mongodbatlas_resource_policy} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ResourcePolicyConfig
    */
    constructor(scope: Construct, id: string, config: ResourcePolicyConfig);
    private _createdByUser;
    get createdByUser(): ResourcePolicyCreatedByUserOutputReference;
    get createdDate(): string;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    get id(): string;
    private _lastUpdatedByUser;
    get lastUpdatedByUser(): ResourcePolicyLastUpdatedByUserOutputReference;
    get lastUpdatedDate(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _orgId?;
    get orgId(): string;
    set orgId(value: string);
    get orgIdInput(): string | undefined;
    private _policies;
    get policies(): ResourcePolicyPoliciesList;
    putPolicies(value: ResourcePolicyPolicies[] | cdktf.IResolvable): void;
    get policiesInput(): cdktf.IResolvable | ResourcePolicyPolicies[] | undefined;
    get version(): string;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
